@@ -77,64 +77,68 @@ import com.openexchange.tools.pipesnfilters.Filter;
  */
 public abstract class OXContextStorageInterface {
 
-    /**
-     * Proxy attribute for the class implementing this interface.
-     */
-    private static Class<? extends OXContextStorageInterface> implementingClass;
-
     private static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(OXContextStorageInterface.class);
 
     protected static final AdminCacheExtended cache = ClientAdminThreadExtended.cache;
 
-    protected static final PropertyHandlerExtended prop = cache.getProperties();
+    private static volatile OXContextStorageInterface instance;
 
     /**
-     * Creates a new instance implementing the group storage interface.
+     * Creates a new instance implementing the context storage interface.
      *
      * @return an instance implementing the group storage interface.
      * @throws com.openexchange.admin.rmi.exceptions.StorageException Storage exception
      */
     public static OXContextStorageInterface getInstance() throws StorageException {
-        synchronized (OXContextStorageInterface.class) {
-            if (null == implementingClass) {
-                final String className = prop.getProp(PropertyHandlerExtended.CONTEXT_STORAGE, null);
-                if (null != className) {
+        OXContextStorageInterface inst = instance;
+        if (null == inst) {
+            synchronized (OXContextStorageInterface.class) {
+                inst = instance;
+                if (null == inst) {
+                    Class<? extends OXContextStorageInterface> implementingClass;
+                    PropertyHandlerExtended prop = cache.getProperties();
+                    final String className = prop.getProp(PropertyHandlerExtended.CONTEXT_STORAGE, null);
+                    if (null != className) {
+                        try {
+                            implementingClass = Class.forName(className).asSubclass(OXContextStorageInterface.class);
+                        } catch (final ClassNotFoundException e) {
+                            log.error("", e);
+                            throw new StorageException(e);
+                        }
+                    } else {
+                        final StorageException storageException = new StorageException("Property for context_storage not defined");
+                        log.error("", storageException);
+                        throw storageException;
+                    }
+
+                    Constructor<? extends OXContextStorageInterface> cons;
                     try {
-                        implementingClass = Class.forName(className).asSubclass(OXContextStorageInterface.class);
-                    } catch (final ClassNotFoundException e) {
+                        cons = implementingClass.getConstructor(new Class[] {});
+                        inst = cons.newInstance(new Object[] {});
+                        instance = inst;
+                    } catch (final SecurityException e) {
+                        log.error("", e);
+                        throw new StorageException(e);
+                    } catch (final NoSuchMethodException e) {
+                        log.error("", e);
+                        throw new StorageException(e);
+                    } catch (final IllegalArgumentException e) {
+                        log.error("", e);
+                        throw new StorageException(e);
+                    } catch (final InstantiationException e) {
+                        log.error("", e);
+                        throw new StorageException(e);
+                    } catch (final IllegalAccessException e) {
+                        log.error("", e);
+                        throw new StorageException(e);
+                    } catch (final InvocationTargetException e) {
                         log.error("", e);
                         throw new StorageException(e);
                     }
-                } else {
-                    final StorageException storageException = new StorageException("Property for context_storage not defined");
-                    log.error("", storageException);
-                    throw storageException;
                 }
             }
         }
-        Constructor<? extends OXContextStorageInterface> cons;
-        try {
-            cons = implementingClass.getConstructor(new Class[] {});
-            return cons.newInstance(new Object[] {});
-        } catch (final SecurityException e) {
-            log.error("", e);
-            throw new StorageException(e);
-        } catch (final NoSuchMethodException e) {
-            log.error("", e);
-            throw new StorageException(e);
-        } catch (final IllegalArgumentException e) {
-            log.error("", e);
-            throw new StorageException(e);
-        } catch (final InstantiationException e) {
-            log.error("", e);
-            throw new StorageException(e);
-        } catch (final IllegalAccessException e) {
-            log.error("", e);
-            throw new StorageException(e);
-        } catch (final InvocationTargetException e) {
-            log.error("", e);
-            throw new StorageException(e);
-        }
+        return inst;
     }
 
     /**
