@@ -56,6 +56,7 @@ import com.openexchange.admin.rmi.dataobjects.Context;
 import com.openexchange.admin.rmi.dataobjects.Credentials;
 import com.openexchange.admin.rmi.dataobjects.Database;
 import com.openexchange.admin.rmi.dataobjects.Filestore;
+import com.openexchange.admin.rmi.dataobjects.Quota;
 import com.openexchange.admin.rmi.dataobjects.SchemaSelectStrategy;
 import com.openexchange.admin.rmi.dataobjects.User;
 import com.openexchange.admin.rmi.dataobjects.UserModuleAccess;
@@ -389,6 +390,20 @@ public interface OXContextInterface extends Remote {
      */
     public void enableAll(final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException;
 
+    /**
+     * Get specified context details
+     *
+     * @param ctx A new Context object, this should not have been used before or a one returned from a previous call to this API. The context IDs of these objects should be set.
+     * @param auth The context-specific credentials
+     * @return
+     * @throws RemoteException
+     * @throws InvalidCredentialsException
+     * @throws NoSuchContextException
+     * @throws StorageException
+     * @throws InvalidDataException
+     */
+    public Context getOwnData(Context ctx, Credentials auth) throws RemoteException,InvalidCredentialsException,NoSuchContextException,StorageException, InvalidDataException;
+
     /**
      * Get specified context details
      *
@@ -472,7 +487,21 @@ public interface OXContextInterface extends Remote {
     public void changeCapabilities(Context ctx, Set<String> capsToAdd, Set<String> capsToRemove, Set<String> capsToDrop, Credentials auth) throws RemoteException,InvalidCredentialsException,NoSuchContextException,StorageException, InvalidDataException;
 
     /**
-     * Changes specified context's capabilities.
+     * Gets the configured quotas in given context.
+     *
+     * @param ctx The context
+     * @param auth The credentials
+     * @return The configured quota
+     * @throws RemoteException
+     * @throws InvalidCredentialsException
+     * @throws NoSuchContextException
+     * @throws StorageException
+     * @throws InvalidDataException
+     */
+    public Quota[] listQuotas(Context ctx, Credentials auth) throws RemoteException,InvalidCredentialsException,NoSuchContextException,StorageException, InvalidDataException;
+
+    /**
+     * Changes specified context's quota for a certain module.
      *
      * @param ctx A new Context object, this should not have been used before or a one returned from a previous call to this API.
      * @param module The module to apply quota to
@@ -616,17 +645,4 @@ public interface OXContextInterface extends Remote {
      */
     @Deprecated
     public boolean checkExists(Context ctx, Credentials auth) throws RemoteException, InvalidDataException, StorageException, InvalidCredentialsException;
-
-    /**
-     * Checks the consistencies for the count tables
-     *
-     * @param checkDatabaseCounts Whether to check the counts related to context to database/schema associations
-     * @param checkFilestoreCounts Whether to check the counts related to context to filestore associations
-     * @param auth Credentials for authenticating against server
-     * @throws com.openexchange.admin.rmi.exceptions.StorageException When an error in the subsystems occurred
-     * @throws com.openexchange.admin.rmi.exceptions.InvalidCredentialsException When the supplied credentials were not correct or invalid
-     * @throws RemoteException General RMI Exception
-     */
-    public void checkCountsConsistency(boolean checkDatabaseCounts, boolean checkFilestoreCounts, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException;
-
 }
