@@ -204,4 +204,39 @@ public class UserAdapter implements User {
         return delegate.toString();
     }
 
+    @Override
+    public boolean isGuest() {
+        return false;
+    }
+
+    @Override
+    public int getCreatedBy() {
+        return 0;
+    }
+
+    @Override
+    public String[] getFileStorageAuth() {
+        return new String[2];
+    }
+
+    @Override
+    public long getFileStorageQuota() {
+        return 0;
+    }
+
+    @Override
+    public int getFilestoreId() {
+        return -1;
+    }
+
+    @Override
+    public String getFilestoreName() {
+        return null;
+    }
+
+    @Override
+    public int getFileStorageOwner() {
+        return -1;
+    }
+
 }
