@@ -55,12 +55,14 @@ import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Types;
 import java.util.ArrayList;
+import com.openexchange.admin.daemons.ClientAdminThread;
 import com.openexchange.admin.rmi.dataobjects.Context;
 import com.openexchange.admin.rmi.dataobjects.Resource;
 import com.openexchange.admin.rmi.exceptions.PoolException;
 import com.openexchange.admin.rmi.exceptions.StorageException;
 import com.openexchange.admin.storage.sqlStorage.OXResourceSQLStorage;
 import com.openexchange.admin.tools.AdminCache;
+import com.openexchange.admin.tools.PropertyHandler;
 import com.openexchange.database.Databases;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.delete.DeleteEvent;
@@ -75,7 +77,13 @@ public class OXResourceMySQLStorage extends OXResourceSQLStorage implements OXMy
 
     private final static org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(OXResourceMySQLStorage.class);
 
+    private final AdminCache cache;
+    private final PropertyHandler prop;
+
     public OXResourceMySQLStorage() {
+        super();
+        this.cache = ClientAdminThread.cache;
+        this.prop = cache.getProperties();
     }
 
     @Override
