@@ -86,177 +86,179 @@ public class OXAdminPoolDBPool implements OXAdminPoolInterface {
 
     @Override
     public Connection getConnectionForConfigDB() throws PoolException {
-        final Connection con;
         try {
-            con = getService().getWritable();
+            return getService().getWritable();
         } catch (OXException e) {
             log.error("Error pickup configdb database write connection from pool!", e);
             throw new PoolException(e.getMessage());
         }
-        return con;
     }
 
     @Override
     public Connection getWriteConnectionForConfigDB() throws PoolException {
-        final Connection con;
         try {
-            con = getService().getWritable();
+            return getService().getWritable();
         } catch (OXException e) {
             log.error("Error pickup configdb database write connection from pool!", e);
             throw new PoolException(e.getMessage());
         }
-        return con;
     }
 
     @Override
     public Connection getReadConnectionForConfigDB() throws PoolException {
-        final Connection con;
         try {
-            con = getService().getReadOnly();
+            return getService().getReadOnly();
         } catch (OXException e) {
             log.error("Error pickup configdb database read connection from pool!", e);
             throw new PoolException(e.getMessage());
         }
-        return con;
     }
 
     @Override
     public Connection getConnectionForContext(int contextId) throws PoolException {
-        final Connection con;
         try {
-            con = getService().getWritable(contextId);
+            return getService().getWritable(contextId);
         } catch (OXException e) {
             log.error("Error pickup context database write connection from pool!", e);
             throw new PoolException(e.getMessage());
         }
-        return con;
     }
 
     @Override
     public Connection getConnection(int poolId, String schema) throws PoolException {
-        final Connection con;
         try {
-            con = getService().get(poolId, schema);
+            return getService().get(poolId, schema);
         } catch (OXException e) {
             log.error("Error pickup context database write connection from pool!", e);
             throw new PoolException(e.getMessage());
         }
-        return con;
     }
 
     @Override
     public Connection getConnectionForContextNoTimeout(int contextId) throws PoolException {
-        final Connection con;
         try {
-            con = getService().getForUpdateTask(contextId);
+            return getService().getForUpdateTask(contextId);
         } catch (OXException e) {
             log.error("Error pickup context database write connection from pool!", e);
             throw new PoolException(e.getMessage());
         }
-        return con;
     }
 
     @Override
     public boolean pushConnectionForConfigDB(Connection con) throws PoolException {
-        try {
-            if (con != null && !con.getAutoCommit() && !con.isClosed()) {
-                con.setAutoCommit(true);
+        if (null != con) {
+            try {
+                if (!con.getAutoCommit() && !con.isClosed()) {
+                    con.setAutoCommit(true);
+                }
+            } catch (SQLException e) {
+                log.error("Error pushing configdb write connection to pool!", e);
+                throw new PoolException(e.getMessage());
+            } finally {
+                getService().backWritable(con);
             }
-        } catch (SQLException e) {
-            log.error("Error pushing configdb write connection to pool!", e);
-            throw new PoolException(e.getMessage());
-        } finally {
-            getService().backWritable(con);
         }
         return true;
     }
 
     @Override
     public boolean pushReadConnectionForConfigDB(Connection con) throws PoolException {
-        try {
-            if (con != null && !con.getAutoCommit() && !con.isClosed()) {
-                con.setAutoCommit(true);
+        if (null != con) {
+            try {
+                if (!con.getAutoCommit() && !con.isClosed()) {
+                    con.setAutoCommit(true);
+                }
+            } catch (SQLException e) {
+                log.error("Error pushing configdb read connection to pool!", e);
+                throw new PoolException(e.getMessage());
+            } finally {
+                getService().backReadOnly(con);
             }
-        } catch (SQLException e) {
-            log.error("Error pushing configdb read connection to pool!", e);
-            throw new PoolException(e.getMessage());
-        } finally {
-            getService().backReadOnly(con);
         }
         return true;
     }
 
     @Override
     public boolean pushWriteConnectionForConfigDB(Connection con) throws PoolException {
-        try {
-            if (con != null && !con.getAutoCommit() && !con.isClosed()) {
-                con.setAutoCommit(true);
+        if (null != con) {
+            try {
+                if (!con.getAutoCommit() && !con.isClosed()) {
+                    con.setAutoCommit(true);
+                }
+            } catch (SQLException e) {
+                log.error("Error pushing configdb write connection to pool!", e);
+                throw new PoolException(e.getMessage());
+            } finally {
+                getService().backWritable(con);
             }
-        } catch (SQLException e) {
-            log.error("Error pushing configdb write connection to pool!", e);
-            throw new PoolException(e.getMessage());
-        } finally {
-            getService().backWritable(con);
         }
         return true;
     }
 
     @Override
     public boolean pushConnectionForContext(int contextId, Connection con) throws PoolException {
-        try {
-            if (con != null && !con.getAutoCommit() && !con.isClosed()) {
-                con.setAutoCommit(true);
+        if (null != con) {
+            try {
+                if (!con.getAutoCommit() && !con.isClosed()) {
+                    con.setAutoCommit(true);
+                }
+            } catch (SQLException e) {
+                log.error("Error pushing context database write connection to pool!", e);
+                throw new PoolException(e.getMessage());
+            } finally {
+                getService().backWritable(contextId, con);
             }
-        } catch (SQLException e) {
-            log.error("Error pushing context database write connection to pool!", e);
-            throw new PoolException(e.getMessage());
-        } finally {
-            getService().backWritable(contextId, con);
         }
         return true;
     }
 
     @Override
     public boolean pushConnectionForContextAfterReading(int contextId, Connection con) throws PoolException {
-        try {
-            if (con != null && !con.getAutoCommit() && !con.isClosed()) {
-                con.setAutoCommit(true);
+        if (null != con) {
+            try {
+                if (!con.getAutoCommit() && !con.isClosed()) {
+                    con.setAutoCommit(true);
+                }
+            } catch (SQLException e) {
+                log.error("Error pushing context database write connection to pool!", e);
+                throw new PoolException(e.getMessage());
+            } finally {
+                getService().backWritableAfterReading(contextId, con);
             }
-        } catch (SQLException e) {
-            log.error("Error pushing context database write connection to pool!", e);
-            throw new PoolException(e.getMessage());
-        } finally {
-            getService().backWritableAfterReading(contextId, con);
         }
         return true;
     }
 
     @Override
     public boolean pushConnectionForContextNoTimeout(int contextId, Connection con) throws PoolException {
-        try {
-            if (null != con && !con.getAutoCommit() && !con.isClosed()) {
-                con.setAutoCommit(true);
+        if (null != con) {
+            try {
+                if (!con.getAutoCommit() && !con.isClosed()) {
+                    con.setAutoCommit(true);
+                }
+            } catch (SQLException e) {
+                log.error("Error pushing context database write connection to pool!", e);
+                throw new PoolException(e.getMessage());
+            } finally {
+                getService().backForUpdateTask(contextId, con);
             }
-        } catch (SQLException e) {
-            log.error("Error pushing context database write connection to pool!", e);
-            throw new PoolException(e.getMessage());
-        } finally {
-            getService().backForUpdateTask(contextId, con);
         }
         return true;
     }
 
     @Override
     public boolean pushConnection(int poolId, Connection con) throws PoolException {
-        try {
-            if (null != con && !con.getAutoCommit() && !con.isClosed()) {
-                con.setAutoCommit(true);
+        if (null != con) {
+            try {
+                if (!con.getAutoCommit() && !con.isClosed()) {
+                    con.setAutoCommit(true);
+                }
+            } catch (SQLException e) {
+                log.error("Error pushing context database write connection to pool!", e);
+                throw new PoolException(e.getMessage());
+            } finally {
+                getService().back(poolId, con);
             }
-        } catch (SQLException e) {
-            log.error("Error pushing context database write connection to pool!", e);
-            throw new PoolException(e.getMessage());
-        } finally {
-            getService().back(poolId, con);
         }
         return true;
     }
